@@ -147,7 +147,7 @@ void my_play(char **argv)
      if(!pid)
      {
 	  char *cmd[4];
-	  setpgrp();
+	  setpgid(pid, 0);
 	  cmd[0]="/bin/sh";
 	  cmd[1]="-c";
 	  cmd[2]=argv[1];
