@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Authors: Louis Bavoil <louis@bavoil.net>
+ * Authors: Louis Bavoil <bavoil@cs.utah.edu>
  *          Fredrik Hbinette <hubbe@hubbe.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -135,19 +135,9 @@ static void adjust_window_size(void)
  * Window reparenting
  *****************************************************************************/
 
-static int reparent_window(void)
+static void change_leader()
 {
      XWMHints *leader_change;
-
-     if (!victim) return 0;
-     if (!WINDOW) return 0;
-     if (old_parent == WINDOW) return 0;
-
-     XSelectInput(display, victim, StructureNotifyMask); 
-     XSync(display, False);
-
-     D("Changing leader of window %x\n",victim);
-
      if ((leader_change = XGetWMHints(display, victim)))
      {
 	  leader_change->flags = (leader_change->flags | WindowGroupHint);
@@ -155,6 +145,19 @@ static int reparent_window(void)
 	  XSetWMHints(display,victim,leader_change);
 	  XFree(leader_change);
      }
+}
+
+static int reparent_window(void)
+{
+     if (!victim) return 0;
+     if (!WINDOW) return 0;
+     if (old_parent == WINDOW) return 0;
+
+     XSelectInput(display, victim, StructureNotifyMask); 
+     XSync(display, False);
+
+     D("Changing leader of window %x\n", victim);
+     change_leader();
      
      D("Reparenting window %x into %x\n", victim, WINDOW);
      XReparentWindow(display, victim, WINDOW, 0, 0);
@@ -170,7 +173,7 @@ static int is_viewable(Display *display, Window w)
 
      if (!XGetWindowAttributes(display, w, &a))
      {
-          D("Could not get Window Attributes");
+          D("Could not get Window Attributes\n");
 	  return 0;
      }
      if (a.map_state != IsViewable)
@@ -377,6 +380,8 @@ static Bool AllXEventsPredicate(Display *dpy, XEvent *ev, char *arg)
 static void check_x_events(void)
 {
      XEvent ev;
+     static char mapped = 0;
+     static char reparented = 0;
 
      while (XCheckIfEvent(display, &ev, AllXEventsPredicate, NULL))
      {
@@ -412,10 +417,12 @@ static void check_x_events(void)
 	       {
 	       case UnmapNotify:
 		    D("UNMAPNOTIFY\n");
+		    mapped = 0;
 		    break;
-	    
+		    
 	       case MapNotify:
 		    D("MAPNOTIFY\n");
+		    mapped = 1;
 		    adjust_window_size();
 		    break;
 	    
@@ -425,14 +432,32 @@ static void check_x_events(void)
 		    {
 			 D("REPARENT NOTIFY to the right window\n");
 			 adjust_window_size();
-			 XMapWindow(display, victim);
+			 reparented = 1;
 		    } else {
 			 D("REPARENT NOTIFY to some other window!\n");
 			 reparent_window();
+			 reparented = 0;
 		    }
 		    break;
 	       }
 	  }
+	  else if (WINDOW && ev.xany.window == WINDOW)
+	  {
+	       switch (ev.type)
+	       {
+	       case ConfigureRequest:
+		    D("ConfigureRequest\n");
+		    set_aspect(ev.xconfigure.width, ev.xconfigure.height);
+		    adjust_window_size();
+		    break;
+	       }
+	  }
+     }
+
+     /* For Window Maker */
+     if (reparented && !mapped) {
+	  D("XMapWindow\n");
+	  XMapWindow(display, victim);
      }
 }
 
@@ -441,6 +466,7 @@ static void check_pipe_fd_events(void)
      static NPWindow wintmp;
      int n;
   
+     Window oldwindow = WINDOW;
      D("Got pipe_fd data, old parent=%x pipe_fd=%d\n", WINDOW, pipe_fd);
   
      n = read(pipe_fd, ((char *)& wintmp),  sizeof(wintmp));
@@ -464,6 +490,12 @@ static void check_pipe_fd_events(void)
   
      D("Got pipe_fd data, new parent=%x\n", WINDOW);
   
+     if (WINDOW && WINDOW != oldwindow && display)
+     {
+	  XSelectInput(display, WINDOW, SubstructureRedirectMask);
+	  XSync(display, False);
+     }
+  
      if (victim)
      {
 	  /* The window has been resized. */
@@ -606,6 +638,7 @@ int main(int argc, char **argv)
 	  {
                /* Has to be done before forking */
 	       save_initial_windows();
+	       XSelectInput(display, WINDOW, SubstructureRedirectMask);
 	       XSelectInput(display, wattr.root, SubstructureNotifyMask);
 	       XSync(display, False);
 	  }
@@ -615,6 +648,7 @@ int main(int argc, char **argv)
       
 	  if (!pid)
 	  {
+	       XSelectInput(display, WINDOW, 0);
 	       XSelectInput(display, wattr.root, 0);
 	       D("Running %s\n", command);
 	       run_app(argv);
