@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Authors: Louis Bavoil <louis@bavoil.net>
+ * Authors: Louis Bavoil <bavoil@cs.utah.edu>
  *          Fredrik Hbinette <hubbe@hubbe.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,6 +21,10 @@
 
 #define THIS (*(data_t **) &(instance->pdata))
 
+#ifndef __GNUC__
+#define __inline
+#endif
+
 /*****************************************************************************
  * Type declarations
  *****************************************************************************/
@@ -891,6 +895,7 @@ NPError NPP_GetValue(void *instance, NPPVariable variable, void *value)
 	  D("GET Plugin name\n");
 	  *((char **)value) = "MozPlugger "
 	       VERSION
+	       " handles QuickTime Windows Media Player Plugin"
 	       ;
 	  break;
 
@@ -903,7 +908,7 @@ NPError NPP_GetValue(void *instance, NPPVariable variable, void *value)
 		   "<a href=http://fredrik.hubbe.net/>Fredrik H&uuml;binette</a> "
 		   "<a href=mailto:hubbe@hubbe.net>&lt;hubbe@hubbe.net&gt</a> "
 		   "and Louis Bavoil "
-		   "<a href=mailto:louis@bavoil.net>&lt;louis@bavoil.net&gt</a>.<br>"
+		   "<a href=mailto:bavoil@cs.utah.edu>&lt;bavoil@cs.utah.edu&gt</a>.<br>"
 		   "For documentation on how to configure mozplugger, "
 		   "check the man page. (type <tt>man&nbsp;mozplugger</tt>)"
 		   " <table> "
@@ -1203,6 +1208,19 @@ void NPP_StreamAsFile(NPP instance,
      new_child(instance, fname);
 }
 
+void resize_window(NPP instance)
+{
+     XSetWindowAttributes attrib;
+     attrib.override_redirect = True;
+     XChangeWindowAttributes(THIS->display, (Window)THIS->windata.window,
+			     CWOverrideRedirect, &attrib);
+     
+     D("Resizing WIN 0x%x to %dx%d!?\n", THIS->windata.window,
+       THIS->windata.width, THIS->windata.height);
+     XResizeWindow(THIS->display, (Window)THIS->windata.window,
+		   THIS->windata.width, THIS->windata.height);
+}
+
 /*****************************************************************************
  * Called when initializing or resizing the window.
  *****************************************************************************/
@@ -1238,18 +1256,10 @@ NPError NPP_SetWindow(NPP instance, NPWindow* window)
      {
 	  D("Writing WIN 0x%x to fd %d\n", window->window, THIS->fd);
 	  write(THIS->fd, (char *)window, sizeof(*window));
-
-	  XSetWindowAttributes attrib;
-	  attrib.override_redirect = True;
-	  XChangeWindowAttributes(THIS->display, (Window)THIS->windata.window,
-				  CWOverrideRedirect, &attrib);
-
-	  D("Resizing WIN 0x%x to %dx%d!?\n", THIS->windata.window,
-	    THIS->windata.width, THIS->windata.height);
-	  XResizeWindow(THIS->display, (Window)THIS->windata.window,
-			THIS->windata.width, THIS->windata.height);
      }
 
+     resize_window(instance);
+
      /* In case Mozilla would call NPP_SetWindow() in a loop. */
      usleep(4000);
 
@@ -1268,6 +1278,7 @@ NPError NPP_DestroyStream(NPP instance, NPStream *stream, NPError reason)
 NPError NPP_Initialize(void)
 {
      D("Initialize\n");
+     do_read_config();
      return NPERR_NO_ERROR;
 }
 
